
API Reference
--------------

A tutorial-like presentation is available at :doc:`usage_api`, using the following API.

.. automodule:: hiwenet
   :members:
   :undoc-members:
   :show-inheritance:


